
/*!
	\file

	\author Igor Mironchik (igor.mironchik at gmail dot com).

	Copyright (c) 2018-2020 Igor Mironchik

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef STOCK_DB_SIGNALS_HPP_INCLUDED
#define STOCK_DB_SIGNALS_HPP_INCLUDED

// Qt include.
#include <QObject>


namespace Stock {

//
// DbSignals
//

//! Signals to inform database.
//! This object is used for synchronization of models and database object.
class DbSignals Q_DECL_FINAL
	:	public QObject
{
	Q_OBJECT

signals:
	//! Product is deleted.
	void productDeleted(
		//! Code of the product. Can't be empty.
		const QString & code );
	//! Product's options are changed.
	void productChanged(
		//! Code of the product. Can't be empty.
		const QString & code,
		//! Place of the product. Can be empty, in this case
		//! product just was added into database.
		const QString & place,
		//! Amount of the product on the place. Ignores if product place is
		//! empty.
		quint64 count,
		//! Description of the product.
		const QString & desc );
	//! Place deleted (only place, stock database is untouched).
	void placeDeleted( const QString & place );
	//! Product's code changed.
	void codeChanged( const QString & newCode, const QString & oldCode );
	//! Place renamed.
	void placeRenamed( const QString & newName, const QString & oldName );

public:
	explicit DbSignals( QObject * parent );
	virtual ~DbSignals();

public slots:
	//! Product is deleted.
	void emitProductDeleted(
		//! Code of the product. Can't be empty.
		const QString & code );
	//! Product's options are changed.
	void emitProductChanged(
		//! Code of the product. Can't be empty.
		const QString & code,
		//! Place of the product. Can be empty, in this case
		//! product just was added into database.
		const QString & place,
		//! Amount of the product on the place. Ignores if product place is
		//! empty.
		quint64 count,
		//! Description of the product.
		const QString & desc );
	//! Product's code changed.
	void emitCodeChanged( const QString & newCode, const QString & oldCode );
	//! Place renamed.
	void emitPlaceRenamed( const QString & newName, const QString & oldName );
	//! Place deleted (only place, stock database is untouched).
	void emitPlaceDeleted( const QString & place );
}; // class DbSignals

} /* namespace Stock */

#endif // STOCK_DB_SIGNALS_HPP_INCLUDED
